@@ -5,9 +5,6 @@ use strict;
 
 use base qw/Net::IMAP::Server::Command/;
 
-use Encode;
-use Encode::IMAPUTF7;
-
 sub validate {
     my $self = shift;
 
@@ -20,6 +17,16 @@ sub validate {
     my $mailbox = $self->connection->model->lookup( @options );
     return $self->no_command("Mailbox already exists") if $mailbox;
 
+    # This both ensures that the mailbox path is valid UTF-7, and that
+    # there aren't bogusly encoded characters (like '/' -> '&AC8-')
+    my $roundtrip = eval {
+        Encode::encode( 'IMAP-UTF-7',
+            Encode::decode( 'IMAP-UTF-7', $options[0] ) );
+    };
+
+    return $self->bad_command("Invalid UTF-7 encoding")
+        unless $roundtrip eq $options[0];
+
     return 1;
 }
 
